import { useCallback, useState } from "react";

export const useItemActionConfirm = (actionFn) => {
  const [item, setItem] = useState(null);

  const onActionConfirm = useCallback(async () => {
    if (item) {
      const result = await actionFn.run(item);

      if (!result.error) {
        setItem(null);
      }
    }
  }, [item, setItem, actionFn]);

  const onActionCancel = useCallback(() => {
    setItem(null);
  }, [setItem]);

  return [item, setItem, onActionConfirm, onActionCancel];
};

export const useActionConfirm = (actionFn, actionArgs) => {
  const [showConfirm, setShowConfirm] = useState(false);

  const onActionConfirm = useCallback(async () => {
    if (showConfirm) {
      const result = await actionFn.run(actionArgs);

      if (!result.error) {
        setShowConfirm(false);
      }
    }
  }, [showConfirm, setShowConfirm, actionFn, actionArgs]);

  const onActionCancel = useCallback(() => {
    setShowConfirm(false);
  }, [setShowConfirm]);

  return [showConfirm, setShowConfirm, onActionConfirm, onActionCancel];
};

export const useActionState = (actionFn, actionArgs) => {
  const { 0: started, 1: finished, 2: result } = actionFn.useWatch(actionArgs);
  return [started && !finished, result.error ? result.message : null];
};
